/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2013 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.ogm.options.navigation;

/**
 * Entry point to the options navigation API. Let's you define global level options as well as navigate to a specific
 * entity level.
 * <p>
 * Implementations must declare a constructor with a single parameter of type
 * {@link org.hibernate.ogm.options.navigation.impl.ConfigurationContext} and should preferably be derived from
 * {@link org.hibernate.ogm.options.navigation.impl.BaseGlobalContext}.
 *
 * @author Emmanuel Bernard <emmanuel@hibernate.org>
 * @param <G> the type of a provider-specific global context definition, following the self-referential generic type
 * pattern
 * @param <E> the type of provider-specific entity context definition, associated with the specific global context type
 */
public interface GlobalContext<G extends GlobalContext<G, E>, E extends EntityContext<E, ?>> {

	/**
	 * Specify mapping for the entity {@code type}
	 */
	E entity(Class<?> type);

}
