/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.ogm.test.id;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.SequenceGenerator;

/**
 * Test entity for {@link org.hibernate.ogm.id.impl.OgmSequenceGenerator}
 *
 * @author Nabeel Ali Memon <nabeel@nabeelalimemon.com>
 */
@Entity
public class Actor {
	static final transient int INITIAL_VALUE = 1;
	private Long id;
	private String name;
	private String totalMovies;

	@Id
	@GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "actorSequenceGenerator")
	@SequenceGenerator(name = "actorSequenceGenerator",
			sequenceName = "actor_sequence_name",
			initialValue = INITIAL_VALUE,
			allocationSize = 10)
	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getBestMovieTitle() {
		return totalMovies;
	}

	public void setBestMovieTitle(String bestMovieTitle) {
		this.totalMovies = bestMovieTitle;
	}
}
