/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * JBoss, Home of Professional Open Source
 * Copyright 2013-2014 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU Lesser General Public License, v. 2.1.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License,
 * v.2.1 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */
package org.hibernate.ogm.datastore.mongodb.test.options;

import static org.fest.assertions.Assertions.assertThat;

import org.hibernate.ogm.datastore.document.options.AssociationStorage;
import org.hibernate.ogm.datastore.document.options.AssociationStorageType;
import org.hibernate.ogm.datastore.document.options.impl.AssociationStorageOption;
import org.hibernate.ogm.options.navigation.impl.WritableOptionsServiceContext;
import org.hibernate.ogm.options.spi.OptionsContainer;
import org.junit.Before;
import org.junit.Test;

/**
 * Test the {@link AssociationStorage} annotation used to set the {@link AssociationStorageType} in MongoDB.
 *
 * @author Davide D'Alto <davide@hibernate.org>
 */
public class AssociationStorageAnnotationTest {

	private WritableOptionsServiceContext optionsContext;

	@Before
	public void setupContexts() {
		optionsContext = new WritableOptionsServiceContext();
	}

	@Test
	public void testAssociationStorageMappingOptionOnField() throws Exception {
		OptionsContainer fieldOptions = optionsContext.getPropertyOptions( EntityAnnotatedOnField.class, "field" );
		assertThat( fieldOptions.getUnique( AssociationStorageOption.class ) ).isEqualTo( AssociationStorageType.IN_ENTITY );
	}

	@Test
	public void testAssociationStorageMappingOptionOnMethod() throws Exception {
		OptionsContainer methodOptions = optionsContext.getPropertyOptions( EntityAnnotatedOnMethod.class, "method" );
		assertThat( methodOptions.getUnique( AssociationStorageOption.class ) ).isEqualTo( AssociationStorageType.ASSOCIATION_DOCUMENT );
	}

	private static final class EntityAnnotatedOnField {

		@AssociationStorage(AssociationStorageType.IN_ENTITY)
		public String field;

	}

	private static final class EntityAnnotatedOnMethod {

		public String method;

		@AssociationStorage(AssociationStorageType.ASSOCIATION_DOCUMENT)
		public String getMethod() {
			return method;
		}

	}
}
